@@ -11,7 +11,7 @@ use Test2::V0 'subtest';
 
 =head1 NAME
 
-Test2::Aggregate - Aggregate tests
+Test2::Aggregate - Aggregate tests for increased speed
 
 =head1 SYNOPSIS
 
@@ -25,16 +25,15 @@ Test2::Aggregate - Aggregate tests
 
 =head1 VERSION
 
-Version 0.10_03
+Version 0.11_1
 
 =cut
 
-our $VERSION = '0.10_03';
-
+our $VERSION = '0.11_1';
 
 =head1 DESCRIPTION
 
-Aggregates all tests specified in C<dirs> (which can even be individual tests), 
+Aggregates all tests specified with C<dirs> (which can even be individual tests)
 to avoid forking, reloading etc that can help with performance (dramatically if
 you have numerous small tests) and also facilitate group profiling.
 Test files are expected to end in B<.t> and are run as subtests of a single
@@ -46,8 +45,11 @@ tools like Test2). It does not even try to package each test by default, which m
 be good or bad (e.g. redefines), depending on your requirements.
 
 Generally, the way to use this module is to try to aggregate sets of quick tests
-(e.g. unit tests). Try to iterativelly add tests to the aggregator dropping those
-that do not work.
+(e.g. unit tests). Try to iterativelly add tests to the aggregator, dropping those
+that do not work. Trying an entire suite in one go is a bad idea, an incompatible
+test can break the run failing all the subsequent tests. The module can usually
+work with C<Test::More> suites, but will have more issues than when you use the
+more modern C<Test2::Suite> (see notes).
 
 =head1 METHODS
  
@@ -69,7 +71,8 @@ that do not work.
         override      => \%override,          # optional, requires Sub::Override
         stats_output  => $stats_output_path,  # optional
         extend_stats  => 0,                   # optional
-        test_warnings => 0                    # optional
+        test_warnings => 0,                   # optional
+        dry_run       => 0                    # optional
     );
 
 Runs the aggregate tests. Returns a hashref with stats like this:
@@ -90,18 +93,22 @@ The parameters to pass:
  
 =item * C<dirs> (either this or C<lists> is required)
 
-An arrayref containing directories which will be searched recursively,
-or even individual tests. The directories (unless C<shuffle> or C<reverse> are
-true) will be processed and tests run in order specified.
+An arrayref containing directories which will be searched recursively, or even
+individual tests. The directories (unless C<shuffle> or C<reverse> are true)
+will be processed and tests run in order specified. Test files are expected to
+end in C<.t>.
 
 =item * C<lists> (either this or C<dirs> is required)
 
-Arrayref of flat files from which each line will be pushed to C<dirs>
-(so they have a lower precedence - note C<root> still applies).
+Arrayref of flat files from which each line will be pushed to C<dirs> (so they
+have a lower precedence - note C<root> still applies, don't include it in the
+paths inside the list files). If the path does not exist, it will be silently
+ignored, however the "official" way to skip a line without checking it as a path
+is to start with a C<#> (comment).
 
 =item * C<excludes> (optional)
 
-Arrayref of regexes to filter out tests that you want excluded.
+Arrayref of strings with regex patterns to filter out tests that you want excluded.
 
 =item * C<root> (optional)
 
@@ -116,7 +123,9 @@ test. Useful for testing modules with special namespace requirements.
 
 =item * C<package> (optional)
 
-Will package each test in its own namespace (no redefine warnings etc).
+Will package each test in its own namespace. While it will help avoid things like
+redefine warnings, it may break some tests when aggregating them, so it is disabled
+by default.
 
 =item * C<override> (optional)
 
@@ -130,9 +139,9 @@ warning if C<test_warnings> is also set).
 
 =item * C<unique> (optional)
 
-Since v0.11, duplicate tests are by default removed from the running list as that
-could mess up the stats output. You can still set it to a false value to allow
-duplicate tests in the list.
+From v0.11, duplicate tests are by default removed from the running list as that
+could mess up the stats output. You can still define it as false to allow duplicate
+tests in the list.
 
 =item * C<shuffle> (optional)
 
@@ -157,25 +166,36 @@ Tests for warnings over all the tests if set to true - this is added as a final
 test which expects zero as the number of tests which had STDERR output.
 The STDERR output of each test will be printed at the end of the test run (and
 included in the test run result hash), so if you want to see warnings the moment
-they are generated (for debugging etc), then leave this option disabled.
+they are generated leave this option disabled.
+
+=item * C<dry_run> (optional)
+
+Instead of running the tests, will do C<ok($testname)> for each one. Otherwise,
+test order, stats files etc. will be produced normally.
 
 =item * C<stats_output_path> (optional)
 
-C<stats_output_path> when defined specifies a path where a file with running
-time per test (average if multiple iterations are specified), starting with the
-slowest test and passing percentage gets written. On negative C<repeat> the
-stats of each successful run will be written separately instead of the averages.
+C<stats_output_path> specifies a path where a file will be created to print out
+running time per test (average if multiple iterations) and passing percentage.
+Output is sorted from slowest test to fastest. On negative C<repeat> the stats
+of each successful run will be written separately instead of the averages.
 The name of the file is C<caller_script-YYYYMMDDTHHmmss.txt>.
-If C<-> is passed instead of a path, then STDOUT will be used instead.
+If C<'-'> is passed instead of a path, then the output will be written to STDOUT.
 The timing stats are useful because the test harness doesn't normally measure
-time per subtest.
+time per subtest (remember, your individual aggregated tests become subtests).
 
 =item * C<extend_stats> (optional)
 
-This option is to allow for the default output of C<stats_output_path> to be
-fixed/reliable and anything added in future versions will only be written when
-C<extend_stats> is enabled.
-Currently starting date/time in ISO_8601 is added when the extend option is set.
+This option is to make the default output of C<stats_output_path> be fixed, but
+still allow additions in future versions that will only be written with the
+C<extend_stats> option enabled.
+Additions with C<extend_stats> as of current version:
+
+=over 4
+
+- starting date/time in ISO_8601.
+
+=back
 
 =back
 
@@ -201,7 +221,9 @@ sub run_tests {
         warn "Root '$root' does not exist, no tests are loaded."
     } else {
         foreach my $file (@{$args{lists}}) {
-            push @dirs, split(/\r?\n/, read_file("$root$file"));
+            push @dirs,
+              map { /^\s*#/ ? () : $_ }
+              split( /\r?\n/, read_file("$root$file") );
         }
 
         find(
@@ -297,7 +319,7 @@ sub _run_tests {
 
     my $repeat = $args->{repeat};
     $repeat = 1 if $repeat < 0;
-    my %stats;
+    my (%stats, $start);
 
     require Time::HiRes if $args->{stats_output};
 
@@ -309,12 +331,13 @@ sub _run_tests {
             warn "$test->Test2::Aggregate\n" if $args->{test_warnings};
 
             $stats{$test}{test_no} = $count unless $stats{$test}{test_no};
-            my $start = Time::HiRes::time() if $args->{stats_output};
+            $start = Time::HiRes::time() if $args->{stats_output};
             $stats{$test}{timestamp} = _timestamp();
 
             my $result = subtest $iter. "Running test $test" => sub {
-                $args->{package}
-                  ? eval "package Test::$i" . '::'. "$count; do '$test';"
+                $args->{dry_run} ? Test2::V0::ok($test)
+                  : $args->{package}
+                  ? eval "package Test::$i" . '::' . "$count; do '$test';"
                   : do $test;
             };
 
@@ -399,13 +422,6 @@ Unit tests are usually great for aggregating. You could use the hash that C<run_
 returns in a script that tries to add more tests automatically to an aggregate list
 to see which added tests passed and keep them, dropping failures.
 
-The environment variable C<AGGREGATE_TESTS> will be set while the tests are running
-for your convenience. Example usage is a module that can only be loaded once, so
-you load it on the aggregated test file and then use something like this in the
-individual test files:
-
- eval 'use My::Module' unless $ENV{AGGREGATE_TESTS};
-
 Trying to aggregate too many tests into a single one can be counter-intuitive as
 you would ideally want to parallelize your test suite (so a super-long aggregated
 test continuing after the rest are done will slow down the suite). And in general
@@ -418,6 +434,32 @@ only real issue with multiple calls is that if you use C<repeat < 0> on a call,
 C<Test2::Plugin::BailOnFail> is loaded so any subsequent failure, on any following
 C<run_tests> call will trigger a Bail.
 
+=head2 Test::More
+
+If you haven't switched to the C<Test2::Suite> you are generally advised to do so
+for a number of reasons, compatibility with this module being only a very minor
+one. If you are stuck with a C<Test::More> suite, C<Test2::Aggregate> can still
+probably help you more than the similarly-named C<Test::Aggregate...> modules.
+
+Although the module tries to load C<Test2> in a way to not interfere, it is generally
+better to do C<use Test::More;> in your aggregating test (i.e. alongside with
+C<use Test2::Aggregate>.
+
+One more caveat is that C<Test2::Aggregate::run_tests> uses C<subtest> from the
+C<Test2::Suite>, which on rare occasions can return a true value when a C<Test::More>
+subtest fails by running no tests, so you could have a failed test show up as
+having a 100 C<pass_perc> in the C<Test2::Aggregate::run_tests> output.
+
+=head2 $ENV{AGGREGATE_TESTS}
+
+The environment variable C<AGGREGATE_TESTS> will be set while the tests are running
+for your convenience. Example usage is making a test you know cannot run under the
+aggregator check and croak if it was run under it, or a module that can only be loaded
+once, so you load it on the aggregated test file and then use something like this in
+the individual test files:
+
+ eval 'use My::Module' unless $ENV{AGGREGATE_TESTS};
+
 =head1 AUTHOR
 
 Dimitrios Kechagias, C<< <dkechag at cpan.org> >>
